@@ -14,6 +14,10 @@ function()
 {
     version <- unlist(utils::packageVersion("qtlcharts"))
 
-    # make it like #.#-#
-    paste(c(version,".","-")[c(1,4,2,5,3)], collapse="")
+    if (length(version) == 3) {
+        return(paste(c(version, ".", "-")[c(1, 4, 2, 5, 3)],
+            collapse = ""))
+    }
+
+    paste(version, collapse = ".")
 }
